# Building my own mini-Pytorch wrapper

I want to learn deeply about everything hence this reimplementation

Here is the overview of the process:

1. Basics


---

## The Progress is here

* [ ] Basics

---
## Progress Description

### soon
